API reference
===============

Cache Function
----------------------------

.. autofunction:: cache_alchemy.cache

DefaultConfig Object
----------------------------

.. automodule:: cache_alchemy.config
    :members:
    :show-inheritance:

FunctionCacheDependency Object
---------------------------------

.. automodule:: cache_alchemy.dependency.FunctionCacheDependency
    :members:
    :show-inheritance:
